<?php
/**
 * Admin Form - Simple Editing
 *
 */
function om_tools_admin() {
  drupal_set_title(t('OM Tools 2 Settings'));
  $tools = om_tools_get();
  $form = array();
  foreach ($tools as $key => $module) {
    om_tools_settings($form, $module);
  }
  $form['submit'] = array( '#type' => 'submit', '#value' => t('Save Settings'), );

  return $form;
}


/**
 * OM Tools requires tools dynamically
 *
 */
function om_tools_settings(&$form, $module = NULL) {
  $om_tools_values = variable_get('om_tools', '');
  //dsm($om_tools_values);  
  $default_values = $om_tools_values[$module];
  
  if (module_exists($module)) {
    include_once(drupal_get_path('module', 'om_tools') . '/tools/' . $module . '/' . $module . '.inc');
    $function = 'om_' . $module . '_tools';
    if (function_exists($function)) {
      return $function($form, $default_values);  
    }
  }
}   


/**
 * 1 Submit for all settings
 *
 */
function om_tools_admin_submit($form, $form_state) {
  $form_values = $form_state['values'];
  $tools = om_tools_get();
    
  //dsm($form_values);
  $om_tools = array();
  foreach ($form_values as $name => $value) {
    list($module) = explode('_', $name);
    if (in_array($module, $tools)) $om_tools[$module][$name] = $value;
  }
  //dsm($om_tools);
  // Save all settings in 1 variable
  variable_set('om_tools', $om_tools);
  
  drupal_set_message(t('Your settings has been saved. <strong>NOTE: When you reset any tool, hit "Save Settings" twice (2X) to take effect.</strong>'));
} 


/**
 * Admin Form - Advanced Editing
 *
 */
function om_tools_admin_advanced($form, &$form_state) {

  drupal_set_title(t('OM Tools 2 Advanced Editing'));
  
  $om_tools_values = variable_get('om_tools', '');
  //dsm($om_tools_values);

  $om_tools_array = '$om_tools = array(' . "\n"; 
   
  foreach ($om_tools_values as $tool => $tools_values) {
    // first level array key
    $om_tools_array .= "\t" . '\'' . $tool . '\' => array(' . "\n";
    
    foreach ($tools_values as $tool_var => $value) {
      // second leve key value pair
      if (!is_numeric($value)) $value = '\'' . $value . '\'';         
      $om_tools_array .= "\t\t" . '\'' . $tool_var . '\' => ' . $value . ',' . "\n";    
    }
    // each sub array closing
    $om_tools_array .= "\t" . '),' . "\n";   
  }
  // var closing
  $om_tools_array .= ');';  
  
  $form = array();  
  $form['om_tools_admin_advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('OM Tools variable content'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
    '#description' => 'Edit all settings without the hassle of collapsing forms. Use this only if you really know what you\'re doing. You can always Backup/Restore your settings.',
  );
  $form['om_tools_admin_advanced']['admin_advanced'] = array(
    '#type' => 'textarea',
    '#title' => t(''),
    '#rows' => 30,
    '#default_value' => $om_tools_array,
  );  
  $form['submit'] = array( '#type' => 'submit', '#value' => t('Save'), );  
  $form['backup'] = array( '#type' => 'submit', '#value' => t('Backup'), );    
  $form['restore'] = array( '#type' => 'submit', '#value' => t('Restore'), );    
    
  return $form;
}

/**
 * Admin Advanced Submit
 * 
 */
function om_tools_admin_advanced_submit($form, $form_state) {
  
  $form_values = $form_state['values'];
  //dsm($form_values['om_tools_admin_advanced']['admin_advanced']);
 
  ob_start();
  eval($form_values['om_tools_admin_advanced']['admin_advanced']);
  ob_end_clean();
  //dsm($om_tools);
  // update data
  if ($form_values['op'] == t('Save')) { 
    variable_set('om_tools', $om_tools);
    drupal_set_message(t('All settings are saved.'));
  }
  if ($form_values['op'] == t('Backup')) {
    variable_set('om_tools_backup', $om_tools);
    drupal_set_message(t('Backup is successful.'));
  }
  if ($form_values['op'] == t('Restore')) {
    $om_tools = variable_get('om_tools_backup', '');
    if (!empty($om_tools)) {
      variable_set('om_tools', $om_tools);    
      drupal_set_message(t('All settings are restored from backup.'));
    }
    else {
      drupal_set_message(t('Backup file is empty.'));    
    }
  }
}



