<?php
/**
 * @file
 * Block Classes Utility
 */

/**
 * OM Tools Block Utility Settings
 *
 */
function om_block_tools(&$form, $block_classes) {
  drupal_add_js(drupal_get_path('module', 'om_tools') . '/tools/block/js/block.js', 'module');
  dsm($blocks_classes);
  // get new blocks
  $block_classes = om_block_classes_get($block_classes, FALSE);  
  
  // reset block classes
  if ($block_classes['block_classes_reset']) {
    $block_classes['block_classes_reset'] = 0;
    $block_classes = om_block_classes_get($block_classes, TRUE);
  }  
  
  // Block Tool   
  $form['om_block_tools'] = array(
    '#type' => 'fieldset',
    '#title' => t('Block'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['om_block_tools']['block_classes'] = array(
    '#type' => 'fieldset',
    '#title' => t('Block Classes'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['om_block_tools']['block_classes']['block_classes_switch'] = array(
    '#type' => 'checkbox',
    '#title' =>  t('Add custom block classes'),
    '#default_value' => $block_classes['block_classes_switch'],
  );  
  $form['om_block_tools']['block_classes']['block_classes_settings'] = array(
    '#type' => 'fieldset',
    '#attributes' => array( 'id' => 'om-group-block-classes-settings'),
    '#title' => t('Block Classes Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#description' => t('If you\'re not using <strong>OM Base Theme 2</strong>, you need to add this to your <strong>block.tpl.php</strong>, ... class="block block-&lt;?php print $block->module ?&gt; <strong>&lt;?php print $om_block_classes; ?&gt;</strong>">'),
  );  
  $excluded = array('block_classes_switch', 'block_classes_reset');
  foreach ($block_classes as $name => $val) {
    if (!in_array($name, $excluded)) {
      $module = explode('_', $name);
      $delta = !empty($module[4]) ? $module[3] . '_' . $module[4]: $module[3];
      $form['om_block_tools']['block_classes']['block_classes_settings']['block_classes_' . $module[2] . '_' . $delta] = array(
        '#type' => 'textfield',
        '#title' => t('ID: ' . 'block-' . $module[2] . '-' . $delta . ' <a href="' . base_path() . 'admin/build/block/configure/' . $module[2] . '/' . $module[3] . '?destination=admin/settings/om_tools">Edit</a>'),
        '#default_value' => $val,
      );  
    }
  }
  $form['om_block_tools']['block_classes']['block_classes_reset'] = array(
    '#type' => 'checkbox',
    '#title' => t('Reset to default values.'),      
    '#default_value' => $block_classes['block_classes_reset'],
  );                   
  return $form;  
}


/**
 * Override or insert om variables into the templates.
 */
function om_block_preprocess_block(&$vars) {
  $block = $vars['block'];
  $block_classes = $vars['om_block_tools_values'];  
  //dsm($block);
  if ($block_classes['block_classes_switch']) {
    $vars['om_block_classes'] = $block_classes['block_classes_' . $block->module . '_' . $block->delta];
  }
}
 

/**
 * default blocks classes
 *
 */
function om_block_classes_get($block_classes = array(), $reset = FALSE) {
  $theme_default = variable_get('theme_default', 'garland');
  
  // boxes table is for custom blocks
  $box_sql = "SELECT bid, info FROM {boxes} ORDER BY info ASC";
  
  $box_result = db_query($box_sql);

  $box_classes = array();
  while ($box_record = db_fetch_object($box_result)) {
    $box_classes[$box_record->bid] = om_tools_class_safe($box_record->info);
  }

  // default, module generated blocks
  $block_sql = "SELECT module, delta FROM {blocks} WHERE theme = '%s' ORDER BY module, delta ASC";
  
  $block_result = db_query($block_sql, $theme_default);
  
  $current_blocks = array();
  
  while ($block_record = db_fetch_object($block_result)) {
    // new blocks
    if (!isset($block_classes['block_classes_' . $block_record->module . '_' . $block_record->delta]) || ($reset == TRUE)) { 
      if ($block_record->module == 'block') {
        $classes = 'block-' . $box_classes[$block_record->delta];
      }
      else {
        $classes = 'block-' . $block_record->module . '-' . $block_record->delta;
      }
    }
    // old blocks
    else { 
      $classes = $block_classes['block_classes_' . $block_record->module . '_' . $block_record->delta];
    }
    // this will ignore non-existing blocks
    $current_blocks['block_classes_' . $block_record->module . '_' . $block_record->delta] = $classes;  
  }
  $current_blocks['block_classes_switch'] = $block_classes['block_classes_switch'];
  
  ksort($current_blocks);
  
  return $current_blocks;
} 



