<?php
/**
 * @file
 * System Utility
 */
 
/**
 * OM Tools System Utility Settings
 *
 */
function om_system_tools(&$form, $system_mediaqueries) {
  drupal_add_js(drupal_get_path('module', 'om_tools') . '/tools/system/js/system.js', 'module');
  $maxsizes = '1600, 1440, 1280, 1120, 960, 800, 640, 480';
  $theme_path = path_to_theme();  

  // restores default values on initial install or no block classes variables
  if (!isset($system_mediaqueries['system_mediaqueries_maxsizes']) && !isset($system_mediaqueries['system_mediaqueries_path'])) {
    $system_mediaqueries['system_mediaqueries_maxsizes'] = $maxsizes;
    $system_mediaqueries['system_mediaqueries_path'] = $theme_path;
  }

  // Reset Node Form
  if ( $system_mediaqueries['system_mediaqueries_reset']) {
    $system_mediaqueries['system_mediaqueries_reset'] = 0;  
    $system_mediaqueries['system_mediaqueries_maxsizes'] = $maxsizes;
    $system_mediaqueries['system_mediaqueries_path'] = $theme_path;
  }  

  // System Tool
  $form['om_system_tools'] = array(
    '#type' => 'fieldset',
    '#title' => t('System'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['om_system_tools']['system_mediaqueries'] = array(
    '#type' => 'fieldset',
    '#title' => t('Media Queries'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['om_system_tools']['system_mediaqueries']['system_mediaqueries_switch'] = array(
    '#type' => 'checkbox',
    '#title' =>  t('Enable Media Queries'),
    '#default_value' => $system_mediaqueries['system_mediaqueries_switch'],
  );  
  $form['om_system_tools']['system_mediaqueries']['mediaqueries_settings'] = array(
    '#type' => 'fieldset',
    '#attributes' => array( 'id' => 'om-group-system-mediaqueries-settings'),
    '#title' => t('Media Queries Stylesheet Settings for desktop, tablet, mobile devices.'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#description' => t('Add all desired maximum widths, separated by comma, ex. 960, 800. Then create the stylesheets, ex style960.css, style.800.css, each stylesheet will then be activated depending on the size of browser\'s viewport.'),
  );  
  $form['om_system_tools']['system_mediaqueries']['mediaqueries_settings']['system_mediaqueries_maxsizes'] = array(
    '#type' => 'textarea',
    '#title' => t('Add all max-width for this site.'),
    '#default_value' => $system_mediaqueries['system_mediaqueries_maxsizes'],
    '#rows' => 5,
    '#description' => t('Standard sizes: 1600, 1440, 1280, 1120, 960, 800, 640, 480'),
  );
  $form['om_system_tools']['system_mediaqueries']['mediaqueries_settings']['system_mediaqueries_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Stylesheets path'),
    '#default_value' => $system_mediaqueries['system_mediaqueries_path'],
    '#width' => 30,
    '#description' => t('Where do your media stylesheets located? ex. sites/default/themes/mytheme/css'),
  );          
  $form['om_system_tools']['system_mediaqueries']['system_mediaqueries_reset'] = array(
    '#type' => 'checkbox',
    '#title' => t('Reset to default values.'),      
    '#default_value' => $system_mediaqueries['system_mediaqueries_reset'],
  );                   
  return $form;  
}

/**
 * Override or insert om variables into the templates.
 */
function om_system_preprocess_page(&$vars) {
  $system_mediaqueries = $vars['om_system_tools_values'];

  if ($system_mediaqueries['system_mediaqueries_switch']) {
    /**
     * Mediaqueries
     * http://plugins.jquery.com/project/MediaQueries
     *
     * - rename jquery.mediaqueries.js to mediaqueries.js
     *
     */  
    drupal_add_js(drupal_get_path('module', 'om_tools') . '/contrib/mediaqueries.js', 'module');
    
    $theme_path_default = $system_mediaqueries['system_mediaqueries_path'];
    $styles = explode(',', $system_mediaqueries['system_mediaqueries_maxsizes']);
    foreach ($styles as $key => $style) {
      if (is_numeric($style)) {
        // This is put to $head instead of $styles to avoid collision with OM $styles aggregation
        $vars['head'] .= '<link rel="stylesheet" type="text/css" href="' . base_path() . $theme_path_default . '/style' . trim($style) . '.css" media="only screen and (max-width: ' . $style . 'px)" />';
      }
    } 
  }
  //dsm($vars);
}
 
